VERSION 5.00
Begin VB.UserControl Resizer 
   ClientHeight    =   495
   ClientLeft      =   0
   ClientTop       =   0
   ClientWidth     =   495
   InvisibleAtRuntime=   -1  'True
   Picture         =   "Resizer.ctx":0000
   ScaleHeight     =   495
   ScaleWidth      =   495
   ToolboxBitmap   =   "Resizer.ctx":0D26
End
Attribute VB_Name = "Resizer"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
Attribute VB_Ext_KEY = "PropPageWizardRun" ,"Yes"
Option Explicit
Dim WithEvents ControlParent As Form
Attribute ControlParent.VB_VarHelpID = -1

Private Type CtlStats
   tName        As String
   tLeft        As Single
   tTop         As Single
   tWidth       As Single
   tHeight      As Single
   tFontSize    As Single
   tX1          As Single
   tX2          As Single
   tY1          As Single
   tY2          As Single
End Type

Dim Stats() As CtlStats

'   Control properties
Dim m_ResizeEnabled As Boolean
Dim m_ResizeFont As Boolean
Dim m_MinFormHeight As Integer
Dim m_MinFormWidth As Integer
Dim m_MaxFormHeight As Integer
Dim m_MaxFormWidth As Integer
Dim m_LimitFormSize As Boolean

Public Event ResizeComplete()

Public Property Get LimitFormSize() As Boolean
Attribute LimitFormSize.VB_Description = "Returns/sets whether minimum and maximum form sizes will be enforced."
    LimitFormSize = m_LimitFormSize
End Property

Public Property Let LimitFormSize(ByVal New_LimitFormSize As Boolean)
    m_LimitFormSize = New_LimitFormSize
    PropertyChanged "LimitFormSize"
End Property

Public Property Get MaxFormWidth() As Integer
Attribute MaxFormWidth.VB_Description = "Returns/sets the maximum width the form can be resized to."
    MaxFormWidth = m_MaxFormWidth
End Property

Public Property Let MaxFormWidth(ByVal New_MaxFormWidth As Integer)
    m_MaxFormWidth = New_MaxFormWidth
    PropertyChanged "MaxFormWidth"
End Property

Public Property Get MaxFormHeight() As Integer
Attribute MaxFormHeight.VB_Description = "Returns/sets the maximum height the form can be resized to."
    MaxFormHeight = m_MaxFormHeight
End Property

Public Property Let MaxFormHeight(ByVal New_MaxFormHeight As Integer)
    m_MaxFormHeight = New_MaxFormHeight
    PropertyChanged "MaxFormHeight"
End Property

Public Property Get MinFormWidth() As Integer
Attribute MinFormWidth.VB_Description = "Returns/sets the minimum width the form can be resized to."
    MinFormWidth = m_MinFormWidth
End Property

Public Property Let MinFormWidth(ByVal New_MinFormWidth As Integer)
    m_MinFormWidth = New_MinFormWidth
    PropertyChanged "MinFormWidth"
End Property

Public Property Get MinFormHeight() As Integer
Attribute MinFormHeight.VB_Description = "Returns/sets the minimum height the form can be resized to."
    MinFormHeight = m_MinFormHeight
End Property

Public Property Let MinFormHeight(ByVal New_MinFormHeight As Integer)
    m_MinFormHeight = New_MinFormHeight
    PropertyChanged "MinFormHeight"
End Property

Public Property Get ResizeEnabled() As Boolean
Attribute ResizeEnabled.VB_Description = "Returns/sets whether the controls on the form will be resized."
    ResizeEnabled = m_ResizeEnabled
End Property

Public Property Let ResizeEnabled(New_ResizeEnabled As Boolean)
    m_ResizeEnabled = New_ResizeEnabled
    PropertyChanged "ResizeEnabled"
End Property

Public Property Get ResizeFont() As Boolean
Attribute ResizeFont.VB_Description = "Returns/sets whether the font used in the controls will be resized."
    ResizeFont = m_ResizeFont
End Property

Public Property Let ResizeFont(New_ResizeFont As Boolean)
    m_ResizeFont = New_ResizeFont
    PropertyChanged "ResizeFont"
End Property

Private Sub ControlParent_Resize()
    ResizeControls
End Sub

Private Sub ControlParent_Unload(Cancel As Integer)
Dim retval As Long
    If LimitFormSize Then
'       Restore the window's procedure before closing.
        retval = SetWindowLong(frm.hWnd, GWL_WNDPROC, pOldProc)
    End If
End Sub

Private Sub UserControl_InitProperties()
    ResizeEnabled = True
    ResizeFont = True
    MinFormWidth = Round(Screen.Width / 500) * 100
    MinFormHeight = Round(Screen.Height / 500) * 100
    MaxFormWidth = Round(Screen.Width / 100) * 100
    MaxFormHeight = Round(Screen.Height / 100) * 100
    DoesExist
End Sub

Private Sub UserControl_ReadProperties(PropBag As PropertyBag)
    LimitFormSize = PropBag.ReadProperty("LimitFormSize", False)
    MaxFormWidth = PropBag.ReadProperty("MaxFormWidth", 32000)
    MaxFormHeight = PropBag.ReadProperty("MaxFormHeight", 32000)
    MinFormWidth = PropBag.ReadProperty("MinFormWidth", 100)
    MinFormHeight = PropBag.ReadProperty("MinFormHeight", 100)
    ResizeEnabled = PropBag.ReadProperty("ResizeEnabled", True)
    ResizeFont = PropBag.ReadProperty("ResizeFont", True)
    If Ambient.UserMode Then
        Set ControlParent = UserControl.Parent
        If LimitFormSize Then
            Set frm = UserControl.Parent
            MaxFH = m_MaxFormHeight
            MaxFW = m_MaxFormWidth
            MinFH = m_MinFormHeight
            MinFW = m_MinFormWidth
        End If
    End If
End Sub

Private Sub UserControl_WriteProperties(PropBag As PropertyBag)
    PropBag.WriteProperty "LimitFormSize", m_LimitFormSize, False
    PropBag.WriteProperty "MaxFormWidth", m_MaxFormWidth, 32000
    PropBag.WriteProperty "MaxFormHeight", m_MaxFormHeight, 32000
    PropBag.WriteProperty "MinFormWidth", m_MinFormWidth, 0
    PropBag.WriteProperty "MinFormHeight", m_MinFormHeight, 0
    PropBag.WriteProperty "ResizeEnabled", m_ResizeEnabled, True
    PropBag.WriteProperty "ResizeFont", m_ResizeFont, True
End Sub

Private Sub ControlParent_Load()
    GetStats
    If LimitFormSize Then
'       Set the new window procedure for Form1, saving a pointer to the old one.
        pOldProc = SetWindowLong(frm.hWnd, GWL_WNDPROC, AddressOf WindowProc)
    End If
End Sub

Private Sub GetStats()
Attribute GetStats.VB_Description = "Retrieves all the information needed to resize and move the controls on the form. This run only once when the form is loaded."
Dim ctl As Control
Dim i As Integer

   On Error Resume Next
   
    For Each ctl In ControlParent.Controls
        ReDim Preserve Stats(i)
        Stats(i).tHeight = ctl.Height / ControlParent.ScaleHeight
        Stats(i).tLeft = ctl.Left / ControlParent.ScaleWidth
        Stats(i).tTop = ctl.Top / ControlParent.ScaleHeight
        Stats(i).tWidth = ctl.Width / ControlParent.ScaleWidth
        Stats(i).tName = ctl.Name
        Stats(i).tFontSize = ctl.Font.Size / ControlParent.ScaleHeight
        Stats(i).tX1 = ctl.X1 / ControlParent.ScaleWidth
        Stats(i).tX2 = ctl.X2 / ControlParent.ScaleWidth
        Stats(i).tY1 = ctl.Y1 / ControlParent.ScaleHeight
        Stats(i).tY2 = ctl.Y2 / ControlParent.ScaleHeight
        i = i + 1
    Next ctl

End Sub

Private Sub ResizeControls()
Attribute ResizeControls.VB_Description = "This method is fired each time the parent form is resize. All control resizing occurs here."
Dim ctl As Control
Dim i As Integer

    On Error Resume Next
    
    For i = 0 To UBound(Stats)
        Set ctl = ControlParent.Controls.Item(i)
        If InStr(UCase(ctl.Tag), "CONTROLRESIZE=FALSE") = 0 Then
            ctl.Left = ControlParent.ScaleWidth * Stats(i).tLeft
            ctl.Width = ControlParent.ScaleWidth * Stats(i).tWidth
            ctl.Top = ControlParent.ScaleHeight * Stats(i).tTop
            ctl.Height = ControlParent.ScaleHeight * Stats(i).tHeight
            ctl.X1 = ControlParent.ScaleWidth * Stats(i).tX1
            ctl.X2 = ControlParent.ScaleWidth * Stats(i).tX2
            ctl.Y1 = ControlParent.ScaleHeight * Stats(i).tY1
            ctl.Y2 = ControlParent.ScaleHeight * Stats(i).tY2
            If ResizeFont Then
                If InStr(UCase(ctl.Tag), "FONTRESIZE=FALSE") = 0 Then
                    ctl.Font.Size = ControlParent.ScaleHeight * Stats(i).tFontSize
                End If
            End If
        End If
        Set ctl = Nothing
    Next i
    
    RaiseEvent ResizeComplete

End Sub

Private Sub UserControl_Resize()
    UserControl.Width = 495
    UserControl.Height = 495
End Sub

Private Function DoesExist() As Boolean
Dim ctl As Control
Dim i As Integer
Dim strmess As String

    For Each ctl In UserControl.Parent.Controls
        If TypeOf ctl Is Resizer Then
            i = i + 1
        End If
    Next ctl
    
    If i > 1 Then
        strmess = "Placing more than one Resizer Control on a form can cause "
        strmess = strmess & "your application" & vbCrLf & "crash. Because of "
        strmess = strmess & "this, the second Resizer Control will not be added."

        MsgBox strmess, vbCritical, "Control Load Error"
        SendKeys "{del}"
    End If
End Function
